/*-----------------------------------------------------------------
LOG
    GEM - Graphics Environment for Multimedia

    Pixel color inversion

    Copyright (c) 2000 Guenter Geiger
    For information on usage and redistribution, and for a DISCLAIMER OF ALL
    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.

-----------------------------------------------------------------*/

void mgck_noise_setup();
void mgck_blur_setup();
void mgck_colorize_setup();
void mgck_convolve_setup();
void mgck_despecle_setup();
void mgck_edge_setup();
void mgck_emboss_setup();
void mgck_enhance_setup();
void mgck_gaussblur_setup();
void mgck_implode_setup();
void mgck_medianfilt_setup();
  //void mgck_(morph, MorphImages)
void mgck_oil_setup();
void mgck_plasma_setup();
void mgck_denoise_setup();
void mgck_shade_setup();
void mgck_sharpen_setup();
void mgck_solarize_setup();
void mgck_spread_setup();
  //void mgck_stegano();
  //void mgck_stereo();
void mgck_swirl_setup();
void mgck_threshold_setup();
void mgck_unsharp_setup();
void mgck_wave_setup();
void mgck_resize_setup(); /* ok */


