/*-----------------------------------------------------------------
LOG
    GEM - Graphics Environment for Multimedia

    Pixel color inversion

    Copyright (c) 2000 Guenter Geiger
    For information on usage and redistribution, and for a DISCLAIMER OF ALL
    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.

-----------------------------------------------------------------*/



 mgck_noise_setup();
 mgck_blur_setup();
// mgck_colorize_setup();
// mgck_convolve_setup();
 mgck_despecle_setup();
 mgck_edge_setup();
 mgck_emboss_setup();
 mgck_enhance_setup();
 mgck_gaussblur_setup();
 mgck_implode_setup();
mgck_medianfilt_setup(); /* slow */
  // mgck_morph_setup();
 mgck_oil_setup(); 
// mgck_plasma_setup();
 mgck_denoise_setup();
mgck_shade_setup(); /* fast */
 mgck_sharpen_setup();
mgck_solarize_setup(); /* doesn't work */
mgck_spread_setup(); /* spread */
  // mgck_stegano_setup();
  // mgck_stereo_setup();
mgck_swirl_setup(); /* ok */
mgck_threshold_setup();
   mgck_unsharp_setup();
mgck_wave_setup(); /* ok */
mgck_resize_setup(); /* ok */



